from distutils.core import setup

setup(name='yeyenino',   #模块名字
      version='1.0',   #版本号
      description='字段判断', #描述
      author='yeyenino',     #作者
      author_email='714537539@qq.com',
      py_modules=['yeyenino.autoIncrement']  #要发布的模块
      )